summaryrefslogtreecommitdiff
path: root/data
diff options
context:
space:
mode:
authorGiuseppe Bilotta <giuseppe.bilotta@gmail.com>2008-02-14 09:23:10 +0100
committerGiuseppe Bilotta <giuseppe.bilotta@gmail.com>2008-02-14 09:23:10 +0100
commit3527629fa971d1407d152fecad13fb346c9286da (patch)
tree6201bdc35fa47c9a41e87075dd00e2b9589ede53 /data
parent24bb60775741d3731400f1e430ef6bf3a2e1b933 (diff)
* replace references to old website to references to new site
Diffstat (limited to 'data')
-rw-r--r--data/rbot/plugins/alias.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/data/rbot/plugins/alias.rb b/data/rbot/plugins/alias.rb
index a587736c..bafd8528 100644
--- a/data/rbot/plugins/alias.rb
+++ b/data/rbot/plugins/alias.rb
@@ -12,10 +12,10 @@
# exisitng rbot command and that is run.
#
# == Example Session
# < alias googlerbot *terms => google site:linuxbrit.co.uk/rbot/ <terms>
# > okay
# < googlerbot plugins
# > Results for site:linuxbrit.co.uk/rbot/ plugins: ....
#
# == Security
# By default, only the owner can define and remove aliases, while everyone else can
@@ -171,7 +171,7 @@ class AliasPlugin < Plugin
end.join ' | '
end
when 'create'
- _('"alias <text> => <command>" => add text as an alias of command. Text can contain placeholders marked with : or * for :words and *multiword arguments. The command can contain placeholders enclosed with < > which will be substituded with argument values. For example: alias googlerbot *terms => google site:linuxbrit.co.uk/rbot/ <terms>')
+ _('"alias <text> => <command>" => add text as an alias of command. Text can contain placeholders marked with : or * for :words and *multiword arguments. The command can contain placeholders enclosed with < > which will be substituded with argument values. For example: alias googlerbot *terms => google site:ruby-rbot.org <terms>')
when 'commands'
_('alias list => list defined aliases | alias whatis <alias> => show definition of the alias | alias remove <alias> => remove defined alias | see the "create" topic about adding aliases')
end
@@ -12,10 +12,10 @@
#
# == Example Session
-# < alias googlerbot *terms => google site:linuxbrit.co.uk/rbot/ <terms>
+# < alias googlerbot *terms => google site:ruby-rbot.org <terms>
# > okay
# < googlerbot plugins
@@ -12,10 +12,10 @@
# > okay
# < googlerbot plugins
-# > Results for site:linuxbrit.co.uk/rbot/ plugins: ....
+# > Results for site:ruby-rbot.org plugins: ....
#
# == Security